# To do's and ideas

## To do
- [x] Nicer error message if no network
- [x] Remove duplicate layout code
- [x] DRY time formatting
- [x] Fix truncation of genres and long descifiptions
- [x] Run formatter

## Ideas and possible improvements

- [x] Json output
- [x] Make it possible to turn off colours
- [x] Links to streams
- [ ] Make the lists of upcoming shows align even when the descriptions have different numbers of lines
- [ ] Make it possible to log in and get current songs, favourites etc
- [ ] Play command that starts playing the current show
- [ ] Render map of [Radio Broadcast Locations](https://www.nts.live/explore/location)
